(define-module (gnu packages glicid)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system cmake)
  #:use-module (guix licenses)
  #:use-module (gnu packages gawk)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages commencement)
  #:use-module (guix build-system python)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module ((guix utils) #:select (target-64bit?))
  #:use-module (gnu packages)
  #:use-module (gnu packages admin)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages base)
  #:use-module (gnu packages freeipmi)
  #:use-module (gnu packages linux)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages parallel)
  #:use-module (gnu packages storage)
  #:use-module (gnu packages networking)
  #:use-module (gnu packages gtk)  
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-science)
  #:use-module (gnu packages python-web)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages readline)
  #:use-module (gnu packages tcl)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages commencement)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages chemistry)
  #:use-module (gnu packages sphinx)
  #:use-module (srfi srfi-1)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages sssd)
  #:use-module (gnu packages fabric-management)
  #:use-module (gnu packages benchmark)
  #:use-module (gnu packages messaging)
  #:use-module (gnu packages web)
  #:use-module (gnu packages gnome)
  #:use-module (gnu packages cluster)  
  #:use-module (gnu packages libevent)
  #:use-module (gnu packages xorg)
  #:use-module (gnu packages fontutils)
  #:use-module (gnu packages flex)
  #:use-module (gnu packages bison)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages fontutils)
  #:use-module (guix build-system gnu)
  #:use-module (gnu packages image)
;  #:use-module ((gnu packages gcc) #:select(custom-gcc)) 
)


(define* (custom-gcc gcc name languages
                     #:optional
                     (search-paths (package-native-search-paths gcc))
                     #:key (separate-lib-output? #t))
  "Return a custom version of GCC that supports LANGUAGES.  Use SEARCH-PATHS
as the 'native-search-paths' field."
  (package (inherit gcc)
    (name name)
    (outputs (if separate-lib-output?
                 (package-outputs gcc)
                 (delete "lib" (package-outputs gcc))))
    (native-search-paths search-paths)
    (properties (alist-delete 'hidden? (package-properties gcc)))
    (arguments
     (substitute-keyword-arguments (package-arguments gcc)
       ((#:modules modules %gnu-build-system-modules)
        `(,@modules
          (srfi srfi-1)
          (srfi srfi-26)
          (ice-9 regex)))
       ((#:configure-flags flags)
        `(cons (string-append "--enable-languages="
                              ,(string-join languages ","))
               (remove (cut string-match "--enable-languages.*" <>)
                       ,flags)))
       ((#:phases phases)
        `(modify-phases ,phases
           (add-after 'install 'remove-broken-or-conflicting-files
             (lambda* (#:key outputs #:allow-other-keys)
               (for-each delete-file
                         (find-files (string-append (assoc-ref outputs "out") "/bin")
                                     ".*(c\\+\\+|cpp|g\\+\\+|gcov|gcc|gcc-.*)"))
               #t))))))))

(define %generic-search-paths
  ;; This is the language-neutral search path for GCC.  Entries in $CPATH are
  ;; not considered "system headers", which means GCC can raise warnings for
  ;; issues in those headers.  'CPATH' is the only one that works for
  ;; front-ends not in the C family.
  (list (search-path-specification
         (variable "CPATH")
         (files '("include")))
        (search-path-specification
         (variable "LIBRARY_PATH")
         (files '("lib" "lib64")))))

 (define-public gfortran-11
  (hidden-package
   (custom-gcc gcc-11 "gfortran" '("fortran")
               %generic-search-paths)))
   
   
 (define-public gfortran-10
   (hidden-package
    (custom-gcc gcc-10 "gfortran" '("fortran")
                %generic-search-paths)))



;;;; CUSTOM CCIPL

(define-public gfortran-toolchain-10
  (package (inherit (make-gcc-toolchain gfortran-10))
    (synopsis "Complete GCC tool chain for fortean lang development")
    (description "This package provides a complete GCC tool chain for
fortran lang development to be installed in user profiles.  This includes
fortran, as well as libc (headers and binaries, plus debugging symbols
in the @code{debug} output), and binutils.")))


;;;; CUSTOM CCIPL

(define-public gfortran-toolchain-11
  (package (inherit (make-gcc-toolchain gfortran-11))
    (synopsis "Complete GCC tool chain for fortean lang development")
    (description "This package provides a complete GCC tool chain for
fortran lang development to be installed in user profiles.  This includes
fortran, as well as libc (headers and binaries, plus debugging symbols
in the @code{debug} output), and binutils.")))


;;;;;;;;


(define-public glicid-pmix
 (package
  (name "glicid-pmix-3.1.5")
  (version "3.1.5")
   (source 
    (origin
     (method url-fetch)
     (uri (string-append "https://github.com/openpmix/openpmix/releases/download/v" version "/pmix-" version ".tar.bz2"))
     (sha256 (base32 "1xswdkfcrw123ghcr9gmrb852nzjbl4i6qwrid3xyma42yal34w8"))
    )
   )
  (build-system gnu-build-system)
  (arguments
   `(#:configure-flags
     (list
           (string-append "--with-hwloc=" (assoc-ref %build-inputs "hwloc") )
     )
    )
  )
  (synopsis "MPIX lib")
  (description  "MPIX. More to come. FIXIT")
  (home-page "https://www.gnu.org/software/hello/")
  (license gpl3+)
  (inputs `(
    	    ("libevent", libevent)
            ("hwloc" ,hwloc-2 "lib")
            ("perl", perl)
            ("gcc", gcc-11)
           )
  )
 )
)



(define-public glicid-custom-slurm-19.05
 (package 
  (inherit slurm) 
  (name "glicid-custom-slurm-19.05")
  (version "19.05.6")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "1kj79r8hng5gp98ickgvj3im4gr19nzd3p3p8g6rl75axb8jin7h"))
   ))
   (arguments
   `(#:configure-flags
     (list "--enable-pam" "--sysconfdir=/etc/slurm"
            "--disable-static"
            (string-append "--with-freeipmi=" (assoc-ref %build-inputs "freeipmi"))
            (string-append "--with-hwloc=" (assoc-ref %build-inputs "hwloc"))
            (string-append "--with-json=" (assoc-ref %build-inputs "json-c"))
            (string-append "--with-munge=" (assoc-ref %build-inputs "munge"))
            (string-append "--with-pmix=" (assoc-ref %build-inputs "glicid-pmix"))

            ;; 32-bit support is marked as deprecated and needs to be
            ;; explicitly enabled.
            ;;;; ,@(if (target-64bit?) '() '("--enable-deprecated"))
      
     )
    )
  )

   (inputs `(("gtk+-2" ,gtk+-2)
             ("gcc", gcc-11)
             ("glicid-pmix", glicid-pmix)
                ,@(package-inputs slurm)

   
  ))
  (propagated-inputs
     `(
       ("sssd" ,sssd)
        ))
  
))


(define-public glicid-custom-slurm-20.02
 (package 
  (inherit glicid-custom-slurm-19.05)
  (name "glicid-custom-slurm-20.02")
  (version "20.02.6")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "0ji76jgyny6jqdsi4nj9wmk0ny539aq4vvhp2jx99mwwdzpcv701"))
   ))
))


(define-public glicid-custom-slurm-20.11
 (package 
  (inherit glicid-custom-slurm-20.02)
  (name "glicid-custom-slurm-20.11")
  (version "20.11.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "1s70x6yh60sx63dgmp5rlhq8jcz7kxv9pk8gbs9v1jg8zps5h5bk"))
   ))
))




(define-public glicid-librdkafka-09
 (package 
  (inherit librdkafka) 
  (name "glicid-librdkafka-09")
  (version "0.9.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/edenhill/librdkafka/archive/v" version ".tar.gz"))
    (sha256 (base32 "0938yn1msaq8xcj5z7b3jcdy6rslh9kxmvz01r8rdcgbarlvchy2"))
   ))
))



(define-public glicid-x2go
 (package 
  (name "glicid-x2go")
  (version "4.1.0.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://code.x2go.org/releases/source/x2goserver/x2goserver-" version ".tar.gz"))
    (sha256 (base32 "1l6wd708kbipib4ldprfiihqmj4895nifg0bkws4x97majislxk7"))
   ))

    (native-inputs
     `(("autoconf" ,autoconf)
       ("automake" ,automake)
       ("libtool" ,libtool)))

   (inputs
    `(("perl" , perl)))

   (build-system gnu-build-system)
   (synopsis "X2go")
   (description "X2go")
   (license "not checked")
   (home-page "https://wiki.x2go.org")
  )  
)

;(define-public glicid-gromacs-openmpi
; (package
;  (inherit gromacs)
;  (name "glicid-gromacs-openmpi")
;  (inputs `(("openmpi", openmpi)
;                    ,@(package-inputs gromacs)))
;  (build-system cmake-build-system)
;  (arguments
;       `(#:configure-flags configure-flags)
;               (append configure-flags          (list "-DGMX_MPI=on"
;               "-DCMAKE_C_COMPILER=mpicc"
;               "-DCMAKE_CXX_COMPILER=mpiicxx"
;               ))
;  )
; )
;)


(define-public glicid-gromacs-openmpi
 (package
  (inherit gromacs)
  (name "glicid-gromacs-openmpi")
  (inputs `(("openmpi", openmpi)
   ;;         ("openssh", openssh) ;; only for tests... disabled now
                    ,@(package-inputs gromacs)))
  (build-system cmake-build-system)

   (arguments
       `(#:configure-flags
         (list "-DGMX_DEVELOPER_BUILD=on" ; Needed to run tests
               ;; Unbundling
               "-DGMX_USE_LMFIT=EXTERNAL"
               "-DGMX_BUILD_OWN_FFTW=off"
               "-DGMX_EXTERNAL_BLAS=on"
               "-DGMX_EXTERNAL_LAPACK=on"
               "-DGMX_EXTERNAL_TNG=on"
               "-DGMX_EXTERNAL_ZLIB=on"
               "-DGMX_EXTERNAL_TINYXML2=on"
               ;; special glicid
               "-DGMX_MPI=on"
               "-DCMAKE_C_COMPILER=mpicc"
               "-DCMAKE_CXX_COMPILER=mpicxx"
	       "-DGMX_DOUBLE=off"
	       "-DGMX_OPENMP=on"
               "-DGMX_SIMD=AVX2_256"
               (string-append "-DTinyXML2_DIR="
                              (assoc-ref %build-inputs "tinyxml2"))
               ;; Workaround for cmake/FindSphinx.cmake version parsing that does
               ;; not understand the guix-wrapped `sphinx-build --version' answer
               (string-append "-DSPHINX_EXECUTABLE_VERSION="
                              ,(package-version python-sphinx)))
         #:tests? #f
         #:phases
         (modify-phases %standard-phases
           (add-after 'unpack 'fixes
             (lambda* (#:key inputs #:allow-other-keys)
               ;; Still bundled: part of gromacs, source behind registration
               ;; but free software anyways
               ;;(delete-file-recursively "src/external/vmd_molfile")
               ;; Still bundled: threads-based OpenMPI-compatible fallback
               ;; designed to be bundled like that
               ;;(delete-file-recursively "src/external/thread_mpi")
               ;; Unbundling
               (delete-file-recursively "src/external/lmfit")
               (delete-file-recursively "src/external/clFFT")
               (delete-file-recursively "src/external/fftpack")
               (delete-file-recursively "src/external/build-fftw")
               (delete-file-recursively "src/external/tng_io")
               (delete-file-recursively "src/external/tinyxml2")
               (delete-file-recursively "src/external/googletest")
               (copy-recursively (assoc-ref inputs "googletest-source")
                                 "src/external/googletest")
               ;; This test warns about the build host hardware, disable
               (substitute* "src/gromacs/hardware/tests/hardwaretopology.cpp"
                 (("TEST\\(HardwareTopologyTest, HwlocExecute\\)")
                  "void __guix_disabled()"))
               #t)))))



  )

)



;; pour futures customisations.

;(define-public glicid-openmpi-gcc-10
; (package
;  (inherit openmpi)
;  (name "glicid-openpmi-gcc-10")
;  (inputs `(("gcc-10", gcc-10)
;            ("gfortran-11", gfortran-11)
;                  ,@(package-inputs openmpi)))
;  )
;)

(define-public glicid-rdma-core
(package
    (inherit rdma-core)
    (name "glicid-rdma-core")
    (version "31.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "02ym93k6khfmzm9rml79x9zh1dy8231sygw16r287mhwp0x9mbji"))))
 )
)


(define-public glicid-rdma-core-gcc-11
(package
    (inherit rdma-core)
    (name "glicid-rdma-core-gcc-11")
    (version "32.0")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "1z1i741bcn9vchmkjs8nxj0c0bw0jr53zj74l839n2wrb45f55w1"))))
    (inputs `(("gcc-11", gcc-11)
      ,@(package-inputs rdma-core)))
 )
)

(define-public glicid-libfabric-gcc-11
(package
    (inherit libfabric)
    (name "glicid-libfabric-gcc-11")
    (version "1.11.2")
    (source
     (origin
       (method url-fetch)
       (uri
        (string-append "https://github.com/ofiwg/libfabric/releases/download/v"
                       version "/libfabric-" version ".tar.bz2"))
       (sha256
        (base32 "1nnpfkwxhim2nqjkb1vwrb4wj4j3l6w6yvvy69fqam2snlhshazz"))))

    (inputs `(("gcc-11", gcc-11)
      ,@(package-inputs libfabric)))
 )
)


(define-public glicid-ucx-gcc-11
 (package
  (inherit ucx)
  (name "glicid-ucx-gcc-11")
  (version "1.9.0")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/openucx/ucx/releases/download/v" version "/ucx-" version ".tar.gz" ))
    (sha256 (base32 "1yrmwvjxi3najax1wz4irpzxns6cp74ksdx4i1049mf03n2ci8m7"))
   ))

  (inputs `(("gcc-11", gcc-11)
            ("gfortran-11", gfortran-11)
                  ,@(package-inputs ucx)))
  )
)

(define-public glicid-openmpi-gcc-11
 (package
  (inherit openmpi)
  (name "glicid-openpmi-gcc-11")
  (version "4.1.0")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.open-mpi.org/release/open-mpi/v4.1/openmpi-" version ".tar.gz"))
    (sha256 (base32 "02hlg2pgk1np78dqlplwd5qcgrrymy8s49ng4sdrscqmvp1ng112"))
   ))

  (inputs `(("gcc-11", gcc-11)  
            ("gfortran-11", gfortran-11)
	    ("glicid-ucx-gcc-11",glicid-ucx-gcc-11)
;;            ("glicid-rdma-core",glicid-rdma-core) ;;; segfault !!! 
                  ,@(package-inputs openmpi)))
  )
)  

(define-public glicid-intel-mpi-benchmarks
 (package
  (inherit intel-mpi-benchmarks/openmpi)
  (name "glicid-intel-mpi-benchmarks")
  (inputs `(("glicid-openmpi-gcc-11", glicid-openmpi-gcc-11)  
                  ,@(package-inputs intel-mpi-benchmarks/openmpi)))
  )
)  




(define-public glicid-gromacs-gcc-11
 (package
  (inherit gromacs)
  (name "glicid-gromacs-gcc-11")
  (version "2020.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "http://ftp.gromacs.org/pub/gromacs/gromacs-" version ".tar.gz"))
    (sha256 (base32 "1acjrhcfzpqy2dncblhj97602jbg9gdha4q1bgji9nrj25lq6cch"))
   ))

  (inputs `(("gcc-11", gcc-11)
            ("gfortran-11", gfortran-11)
            ("glicid-openmpi-gcc-11", glicid-openmpi-gcc-11)
                    ,@(package-inputs gromacs)))
))


(define-public glicid-python-nbxmpp
 (package 
  (inherit python-nbxmpp) 
  (name "glicid-python-nbxmpp")
  (version "1.0.2")
  (source
     (origin
       (method url-fetch)
       (uri (pypi-uri "nbxmpp" version))
       (sha256
        (base32
         "0vw5drr077w9ks4crnw6pwa4735ycyjdcm54knc3w4in4x5027wr"))))

))


(define-public glicid-gajim
 (package
  (inherit gajim)
  (name "glicid-gajim")
  (version "1.2.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://gajim.org/downloads/1.2/gajim-" version ".tar.gz"))
    (sha256 (base32 "1gfcp3b5nq43xxz5my8vfhfxnnli726j3hzcgwh9fzrzzd9ic3gx"))
   ))

  (inputs `(("python-packaging", python-packaging)
            ("glicid-python-nbxmpp", glicid-python-nbxmpp)
	    ("python-css-parser", python-css-parser)
       ,@(package-inputs gajim)))

   (propagated-inputs
     `(
       ("glib-networking" ,glib-networking)
       ("libsoup" ,libsoup)
       ("gnutls" , gnutls)
	))
))


;;26.2 is ok : "1ilns8spik1xz2n668pf0awp4n7b3q7n886ml0q3bslb8fmqfl0i"
;;27.1 is ok : "1mqaxzsbhm7kh20dwdrapvx4x86wkbk1wgb2yyjz73l6bymv7vir"
;;28.1 is ok : "04y7wm2an842hf6idlbjvmiqnlh05xb2i9rhdb5ifzw6n3ciz5nr" 
;; 30.0 crash : "1ycvd8sp3giwjbp0x3nvb8q2wrdc50s7lmzf44b9l51qgcnvvq93"
;; 31.0 crash :
;; 32.0 crash : "1z1i741bcn9vchmkjs8nxj0c0bw0jr53zj74l839n2wrb45f55w1"
;; 33.0 crash : "0cnmw04z68x042nkqxg57wijzkf9ysmvr8xxidxhxz0mxwx9impg"

(define-public glicid-specific-rdma-core-gcc-11
  (package
    (inherit rdma-core)
    (name "glicid-specific-rdma-core-gcc-11")
    (version "28.1")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://github.com/linux-rdma/rdma-core"
                                  "/releases/download/v" version "/rdma-core-"
                                  version ".tar.gz"))
              (sha256
               (base32
                "04y7wm2an842hf6idlbjvmiqnlh05xb2i9rhdb5ifzw6n3ciz5nr"))))
      (inputs `(("gcc", gcc-11)
      ,@(package-inputs rdma-core)))

 )
)

(define-public glicid-specific-libfabric-gcc-11
(package
    (inherit libfabric)
    (name "glicid-specific-libfabric-gcc-11")
    (version "1.11.2")
    (source
     (origin
       (method url-fetch)
       (uri
        (string-append "https://github.com/ofiwg/libfabric/releases/download/v"
                       version "/libfabric-" version ".tar.bz2"))
       (sha256
        (base32 "1nnpfkwxhim2nqjkb1vwrb4wj4j3l6w6yvvy69fqam2snlhshazz"))))

    (inputs `(("gcc", gcc-11)
      ("rdma-core", glicid-specific-rdma-core-gcc-11)
      ,@(package-inputs libfabric)))
 )
)

(define-public glicid-specific-ucx-gcc-11
 (package
  (inherit ucx)
  (name "glicid-specific-ucx-gcc-11")
  (version "1.9.0")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/openucx/ucx/releases/download/v" version "/ucx-" version ".tar.gz" ))
    (sha256 (base32 "1yrmwvjxi3najax1wz4irpzxns6cp74ksdx4i1049mf03n2ci8m7"))
   ))

  (inputs `(("gcc", gcc-11)
            ("gfortran", gfortran-11)
            ("libfabric", glicid-specific-libfabric-gcc-11)
	    ("rdma-core",glicid-specific-rdma-core-gcc-11)

                  ,@(package-inputs ucx)))
  )
)


(define-public glicid-specific-openmpi-gcc-11
  (package
    (inherit glicid-openmpi-gcc-11)
    (name "glicid-specific-openmpi-gcc-11")
      (inputs `(
       ("gcc",gcc-11)
       ("rdma-core",glicid-specific-rdma-core-gcc-11)
       ("ucx",glicid-specific-ucx-gcc-11)
       ("libfabric",glicid-specific-libfabric-gcc-11)
      ,@(package-inputs glicid-openmpi-gcc-11)))
  )
)

(define-public glicid-specific-intel-mpi-benchmarks
 (package
  (inherit glicid-intel-mpi-benchmarks)
  (name "glicid-specific-intel-mpi-benchmarks")
  (inputs `(("openmpi", glicid-specific-openmpi-gcc-11)  
                  ,@(package-inputs glicid-intel-mpi-benchmarks)))
  )
)  


(define-public glicid-keepalived
  (package
    (inherit keepalived)
    (name "glicid-keepalived")
    (version "2.1.5")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "http://www.keepalived.org/software/keepalived-"
                    version ".tar.gz"))

              (sha256
               (base32
                "0n92fdlmm251scq2j7w1nqwly8jsla4sxrd0jnfb6nn9qp5pqkfr"))))

   (arguments
   `(#:configure-flags
     (list (string-append "--enable-snmp")
           (string-append "--enable-snmp-checker")
	   (string-append "--enable-snmp-rfc")
     )
    )
      
   )


      (inputs `(("net-snmp", net-snmp)
      ,@(package-inputs keepalived)))



 )
)

(define-public glicid-motif
  (package
    (name "glicid-motif")
    (version "2.3.8")
    (source (origin
              (method url-fetch)
              (uri (string-append "https://sourceforge.net/projects/motif/files/Motif%202.3.8%20Source%20Code/motif-2.3.8.tar.gz/download"))

              (sha256 (base32 "1rxwkrhmj8sfg7dwmkhq885valwqbh26d79033q7vb7fcqv756w5"))
             )
    )
    (build-system gnu-build-system)

(arguments
     `(#:make-flags
;;	       #:make-flags
       (list (string-append "PREFIX=" %output)
;             (string-append "CC=" ,(cc-for-target))
             ;; Xft.h #includes <ft2build.h> without ‘freetype2/’.  The Makefile
             ;; works around this by hard-coding /usr/include & $PREFIX.
             (string-append "CPPFLAGS=-I"
                            (assoc-ref %build-inputs "freetype")
                            "/include/freetype2")
             "V=1")
 )
)

(inputs
      `(("libxext" ,libxext)
        ("libx11", libx11)
        ("freetype",freetype)
	("libxft",libxft)
        ("xbitmaps",xbitmaps)
        ("pkg-config" ,pkg-config)
	("flex" ,flex)
	("bison" ,bison)
        ("libxt" ,libxt)))

  (synopsis "Motif")
    (description "Motif ")
    (home-page "https://sourceforge.net/untested")
    (license " ")

 )
)

(define-public glicid-xmgrace
  (package
    (name "glicid-xmgrace")
    (version "5.1.25")
    (source (origin
              (method git-fetch)
              (uri (git-reference
              (url "https://oauth2:9i-PgbC2w_JEx6DUUqzf@gitlab.univ-nantes.fr/CCIPL/legacy_code_mirror/grace.git")
              (commit (string-append "v" version))))
              (sha256 (base32 "1wb8v0q8xa2akas0swpgdgw1s66i50k7kh1g2f894hnk91fzx56z"))
             )
    )
    (build-system gnu-build-system)

 (arguments
     `(
       #:phases
       (modify-phases %standard-phases
         (add-after 'configure 'patch-/bin/sh
           (lambda _
             (substitute* '("Make.conf")
              (("/bin/sh") (which "bash"))
             )
           ) 
         )
        )
       )
      ) 

    (inputs
      `(
        ("libx11", libx11)
        ("libxft",libxft)
        ("libxt",libxt)
	("libxpm",libxpm)
        ("libxext" ,libxext)
        ("autoconf", autoconf)
        ("glicid-motif" ,glicid-motif)
        ("fontconfig", fontconfig)
        ("gfortran", gfortran)
        ("libjpeg-turbo", libjpeg-turbo)
;;        ("libxmhtml", libxmhtml)
       )
    )


   (synopsis "Xmgrace")
   (description "xmgrace")
   (home-page "https://sourceforge.net/untested")
   (license " ")

 )
)

(use-modules (guix packages))
(use-modules (guix download))
(use-modules (gnu packages ruby))
(use-modules (guix build-system ruby))
(use-modules (guix licenses))



(define-public ruby-asciidoctor-revealjs
 (package
  (name "ruby-asciidoctor-revealjs")
  (version "4.1.0")
  (source
    (origin
      (method url-fetch)
      (uri (rubygems-uri "asciidoctor-revealjs" version))
      (sha256
        (base32
          "03vmbcc3x059h17ry4qwk1p0yar9wgh87l2qssi307gy45cjw2mq"))))
  (build-system ruby-build-system)
  (arguments
 '(#:tests? #f)) 
  (propagated-inputs
    `(("ruby-asciidoctor" ,ruby-asciidoctor)
;      ("ruby-concurrent-ruby" ,ruby-concurrent-ruby)
       ("ruby-concurrent" ,ruby-concurrent)
       ("ruby-asciidoctor-kroki", ruby-asciidoctor-kroki)
      ("ruby-thread-safe" ,ruby-thread-safe)))
  (synopsis
    "Converts AsciiDoc documents into HTML5 presentations designed to be executed by the reveal.js presentation framework.")
  (description
    "Converts AsciiDoc documents into HTML5 presentations designed to be executed by the reveal.js presentation framework.")
  (home-page
    "https://github.com/asciidoctor/asciidoctor-reveal.js")
  (license license:expat))
)

(define-public ruby-asciidoctor-kroki
(package
  (name "ruby-asciidoctor-kroki")
  (version "0.4.0")
  (source
    (origin
      (method url-fetch)
      (uri (rubygems-uri "asciidoctor-kroki" version))
      (sha256
        (base32
          "13gx22xld4rbxxirnsxyrsajy9v666r8a4ngms71611af5afgk6w"))))
  (build-system ruby-build-system)
  (arguments
  '(#:tests? #f))  
  (propagated-inputs
    `(("ruby-asciidoctor" ,ruby-asciidoctor)))
  (synopsis
    "An extension for Asciidoctor to convert diagrams to images using https://kroki.io")
  (description
    "An extension for Asciidoctor to convert diagrams to images using https://kroki.io")
  (home-page
    "https://github.com/Mogztter/asciidoctor-kroki")
  (license license:expat)
)
)


;;; glicid.scm ends here
